diff scripts/java/javamethods.m @ 15772:0f1a143e5002

Overhaul scripts/java directory to conform to Octave core. Update docstrings. Use Octave coding conventions. Use default arguments where possible. Match variable names in docstring to variable names in function. HG: Enter commit message. Lines beginning with 'HG:' are removed. HG: Leave message empty to abort commit. HG: -- HG: user: Rik <rik@octave.org> HG: branch 'default' * errordlg.m, helpdlg.m, inputdlg.m, javaArray.m, javaaddpath.m, javaclasspath.m, javafields.m, javamem.m, javamethods.m, javarmpath.m, listdlg.m, msgbox.m, questdlg.m, warndlg.m: Overhaul functions. Update docstrings. Use Octave coding conventions. Use default arguments where possible. Match variable names in docstring to variable names in function.
author Rik <rik@octave.org>
date Wed, 12 Dec 2012 13:48:47 -0800
parents 54e8c2527a9e
children
line wrap: on
line diff
--- a/scripts/java/javamethods.m
+++ b/scripts/java/javamethods.m
@@ -17,29 +17,31 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function file} {@var{P} =} javamethods (@var{class})
 ## Return the methods of a Java object in the form of a cell 
 ## array of strings.  If no output is requested, print the result to the
 ## standard output.
-## @seealso{methods}
+## @seealso{javafields, java_invoke, javaMethod, javaObject}
 ## @end deftypefn
 
-function retval = javamethods (classname)
+function mtd_names = javamethods (classname)
   
   if (nargin != 1)
     print_usage ();
-  else
-    c_methods = java_invoke ("org.octave.ClassHelper", "getMethods", classname);
-    method_list = strsplit (c_methods, ";");
+  endif
+
+  cls_methods = java_invoke ("org.octave.ClassHelper", "getMethods", classname);
+  method_list = strsplit (cls_methods, ';');
 
-    switch nargout
-      case 0
-        if (! isempty (method_list))
-          disp(method_list);
-        endif
-      case 1
-        retval = cellstr (method_list);
-    endswitch
+  if (nargout == 0)
+    if (! isempty (method_list))
+      disp (method_list);
+    endif
+  else
+    mtd_names = cellstr (method_list);
   endif
 
 endfunction
+
@@ -17,29 +17,31 @@
 
 ## -*- texinfo -*-
-## @deftypefn {Function file} {@var{P} =} javamethods (@var{class})
-## Return the methods of a Java object in the form of a cell 
+## @deftypefn  {Function File} {} javamethods (@var{javaobj})
+## @deftypefnx {Function File} {} javamethods ("@var{classname}")
+## @deftypefnx {Function File} {@var{mtd_names} =} javamethods (@dots{})
+## Return the methods of a Java object or Java class in the form of a cell 
 ## array of strings.  If no output is requested, print the result to the
 ## standard output.